@@ -1,7 +1,7 @@
-# coding=utf-8
-import sys
+# -*- coding: utf-8 -*-
 import warnings
 
+import django
 import six
 from django import forms
 from django.conf import settings
@@ -75,20 +75,26 @@ class BaseEncryptedField(models.Field):
         elif value and (value.startswith(self.prefix)):
             if hasattr(self.crypt, 'Decrypt'):
                 retval = self.crypt.Decrypt(value[len(self.prefix):])
-                if sys.version_info < (3,):
-                    if retval:
-                        retval = retval.decode('utf-8')
+                if six.PY2 and retval:
+                    retval = retval.decode('utf-8')
             else:
                 retval = value
         else:
             retval = value
         return retval
 
+    if django.VERSION < (2, ):
+        def from_db_value(self, value, expression, connection, context):
+            return self.to_python(value)
+    else:
+        def from_db_value(self, value, expression, connection):  # type: ignore
+            return self.to_python(value)
+
     def get_db_prep_value(self, value, connection, prepared=False):
         if value and not value.startswith(self.prefix):
             # We need to encode a unicode string into a byte string, first.
             # keyczar expects a bytestring, not a unicode string.
-            if sys.version_info < (3,):
+            if six.PY2:
                 if type(value) == six.types.UnicodeType:
                     value = value.encode('utf-8')
             # Truncated encrypted content is unreadable,
@@ -109,8 +115,7 @@ class BaseEncryptedField(models.Field):
         return name, path, args, kwargs
 
 
-class EncryptedTextField(six.with_metaclass(models.SubfieldBase,
-                                            BaseEncryptedField)):
+class EncryptedTextField(BaseEncryptedField):
     def get_internal_type(self):
         return 'TextField'
 
@@ -119,18 +124,8 @@ class EncryptedTextField(six.with_metaclass(models.SubfieldBase,
         defaults.update(kwargs)
         return super(EncryptedTextField, self).formfield(**defaults)
 
-    def south_field_triple(self):
-        """Returns a suitable description of this field for South."""
-        # We'll just introspect the _actual_ field.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.TextField"
-        args, kwargs = introspector(self)
-        # That's our definition!
-        return field_class, args, kwargs
 
-
-class EncryptedCharField(six.with_metaclass(models.SubfieldBase,
-                                            BaseEncryptedField)):
+class EncryptedCharField(BaseEncryptedField):
     def __init__(self, *args, **kwargs):
         super(EncryptedCharField, self).__init__(*args, **kwargs)
 
@@ -141,12 +136,3 @@ class EncryptedCharField(six.with_metaclass(models.SubfieldBase,
         defaults = {'max_length': self.max_length}
         defaults.update(kwargs)
         return super(EncryptedCharField, self).formfield(**defaults)
-
-    def south_field_triple(self):
-        """Returns a suitable description of this field for South."""
-        # We'll just introspect the _actual_ field.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.CharField"
-        args, kwargs = introspector(self)
-        # That's our definition!
-        return field_class, args, kwargs
