@@ -13,8 +13,9 @@ more information.
 from __future__ import absolute_import
 
 import json
-import six
 
+import django
+import six
 from django.conf import settings
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
@@ -82,15 +83,19 @@ class JSONField(models.TextField):
         elif isinstance(res, list):
             return JSONList(res)
 
-        return value
+        return res
 
     def get_prep_value(self, value):
         if not isinstance(value, six.string_types):
             return dumps(value)
         return super(models.TextField, self).get_prep_value(value)
 
-    def from_db_value(self, value, expression, connection, context):
-        return self.to_python(value)
+    if django.VERSION < (2, ):
+        def from_db_value(self, value, expression, connection, context):
+            return self.to_python(value)
+    else:
+        def from_db_value(self, value, expression, connection):  # type: ignore
+            return self.to_python(value)
 
     def get_db_prep_save(self, value, connection, **kwargs):
         """Convert our JSON object to a string before we save"""
