@@ -18,13 +18,14 @@ https://github.com/WoLpH/django-admin-generator/
 import re
 import sys
 
+from django.apps import apps
 from django.conf import settings
+from django.core.management.base import LabelCommand, CommandError
 from django.db import models
+from django.utils import six
 
-from django_extensions.compat import get_apps, get_models_for_app
 from django_extensions.management.color import color_style
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityLabelCommand as LabelCommand
 
 # Configurable constants
 MAX_LINE_WIDTH = getattr(settings, 'MAX_LINE_WIDTH', 78)
@@ -62,8 +63,8 @@ from .models import %(models)s
 
 PRINT_ADMIN_CLASS = getattr(settings, 'PRINT_ADMIN_CLASS', '''
 
+@admin.register(%(name)s)
 class %(name)sAdmin(admin.ModelAdmin):%(class_)s
-admin.site.register(%(name)s, %(name)sAdmin)
 ''')
 
 PRINT_ADMIN_PROPERTY = getattr(settings, 'PRINT_ADMIN_PROPERTY', '''
@@ -74,7 +75,7 @@ class UnicodeMixin(object):
     """Mixin class to handle defining the proper __str__/__unicode__
     methods in Python 2 or 3."""
 
-    if sys.version_info[0] >= 3:  # Python 3
+    if six.PY3:  # Python 3
         def __str__(self):
             return self.__unicode__()
     else:  # Python 2
@@ -83,13 +84,13 @@ class UnicodeMixin(object):
 
 
 class AdminApp(UnicodeMixin):
-    def __init__(self, app, model_res, **options):
-        self.app = app
+    def __init__(self, app_config, model_res, **options):
+        self.app_config = app_config
         self.model_res = model_res
         self.options = options
 
     def __iter__(self):
-        for model in get_models_for_app(self.app):
+        for model in self.app_config.get_models():
             admin_model = AdminModel(model, **self.options)
 
             for model_re in self.model_res:
@@ -119,7 +120,7 @@ class AdminApp(UnicodeMixin):
     def __repr__(self):
         return '<%s[%s]>' % (
             self.__class__.__name__,
-            self.app,
+            self.app.name,
         )
 
 
@@ -164,7 +165,10 @@ class AdminModel(UnicodeMixin):
     def _process_many_to_many(self, meta):
         raw_id_threshold = self.raw_id_threshold
         for field in meta.local_many_to_many:
-            related_model = getattr(field.related, 'related_model', field.related.model)
+            if hasattr(field, 'remote_field'):
+                related_model = getattr(field.remote_field, 'related_model', field.remote_field.model)
+            else:
+                raise CommandError("Unable to process ManyToMany relation")
             related_objects = related_model.objects.all()
             if related_objects[:raw_id_threshold].count() < raw_id_threshold:
                 yield field.name
@@ -180,7 +184,10 @@ class AdminModel(UnicodeMixin):
         raw_id_threshold = self.raw_id_threshold
         list_filter_threshold = self.list_filter_threshold
         max_count = max(list_filter_threshold, raw_id_threshold)
-        related_model = getattr(field.related, 'related_model', field.related.model)
+        if hasattr(field, 'remote_field'):
+            related_model = getattr(field.remote_field, 'related_model', field.remote_field.model)
+        else:
+            raise CommandError("Unable to process ForeignKey relation")
         related_count = related_model.objects.all()
         related_count = related_count[:max_count].count()
 
@@ -197,17 +204,18 @@ class AdminModel(UnicodeMixin):
         if field in parent_fields:
             return
 
-        self.list_display.append(field.name)
+        field_name = six.text_type(field.name)
+        self.list_display.append(field_name)
         if isinstance(field, LIST_FILTER):
             if isinstance(field, models.ForeignKey):
                 self._process_foreign_key(field)
             else:
-                self.list_filter.append(field.name)
+                self.list_filter.append(field_name)
 
         if field.name in self.search_field_names:
-            self.search_fields.append(field.name)
+            self.search_fields.append(field_name)
 
-        return field.name
+        return field_name
 
     def __unicode__(self):
         return ''.join(self._unicode_generator())
@@ -290,10 +298,12 @@ class AdminModel(UnicodeMixin):
 
 class Command(LabelCommand):
     help = '''Generate a `admin.py` file for the given app (models)'''
-    args = "[app_name]"
+    # args = "[app_name]"
     can_import_settings = True
 
     def add_arguments(self, parser):
+        parser.add_argument('app_name')
+        parser.add_argument('model_name', nargs='*')
         parser.add_argument(
             '-s', '--search-field', action='append',
             default=SEARCH_FIELD_NAMES,
@@ -322,26 +332,22 @@ class Command(LabelCommand):
             'it will be added to `list_filter` [default: %(default)s]')
 
     @signalcommand
-    def handle(self, *args, **kwargs):
+    def handle(self, *args, **options):
         self.style = color_style()
-        installed_apps = dict((a.__name__.rsplit('.', 1)[0], a) for a in get_apps())
 
-        # Make sure we always have args
-        if not args:
-            args = [False]
-        app = args[0]
-        if not installed_apps.get(app):
+        app_name = options['app_name']
+        try:
+            app = apps.get_app_config(app_name)
+        except LookupError:
             print(self.style.WARN('This command requires an existing app name as argument'))
             print(self.style.WARN('Available apps:'))
-            for app in sorted(installed_apps):
-                print(self.style.WARN('    %s' % app))
+            app_labels = [app.label for app in apps.get_app_configs()]
+            for label in sorted(app_labels):
+                print(self.style.WARN('    %s' % label))
             sys.exit(1)
 
         model_res = []
-        for arg in args[1:]:
+        for arg in options['model_name']:
             model_res.append(re.compile(arg, re.IGNORECASE))
 
-        self.handle_app(app, model_res, **kwargs)
-
-    def handle_app(self, app, model_res, **options):
-        print(AdminApp(app, model_res, **options))
+        self.stdout.write(AdminApp(app, model_res, **options).__str__())
