@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 """
 runprofileserver.py
 
@@ -14,16 +14,13 @@ import sys
 from datetime import datetime
 
 from django.conf import settings
-from django.core.management.base import CommandError
+from django.contrib.staticfiles.handlers import StaticFilesHandler
+from django.core.management.base import BaseCommand, CommandError
+from django.core.servers.basehttp import get_internal_wsgi_application
 
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
-try:
-    from django.contrib.staticfiles.handlers import StaticFilesHandler
-    USE_STATICFILES = 'django.contrib.staticfiles' in settings.INSTALLED_APPS
-except ImportError as e:
-    USE_STATICFILES = False
+USE_STATICFILES = 'django.contrib.staticfiles' in settings.INSTALLED_APPS
 
 
 class KCacheGrind(object):
@@ -96,35 +93,46 @@ class Command(BaseCommand):
     args = '[optional port number, or ipaddr:port]'
 
     def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
+        parser.add_argument(
+            'addrport', nargs='?',
+            help='Optional port number, or ipaddr:port'
+        )
         parser.add_argument(
             '--noreload', action='store_false', dest='use_reloader',
             default=True,
             help='Tells Django to NOT use the auto-reloader.')
         parser.add_argument(
-            '--adminmedia', dest='admin_media_path', default='',
-            help='Specifies the directory from which to serve admin media.')
+            '--nothreading', action='store_false', dest='use_threading', default=True,
+            help='Tells Django to NOT use threading.',
+        )
         parser.add_argument(
             '--prof-path', dest='prof_path', default='/tmp',
             help='Specifies the directory which to save profile information '
-            'in.')
+            'in.'
+        )
         parser.add_argument(
             '--prof-file', dest='prof_file',
             default='{path}.{duration:06d}ms.{time}',
             help='Set filename format, default if '
-            '"{path}.{duration:06d}ms.{time}".')
+            '"{path}.{duration:06d}ms.{time}".'
+        )
         parser.add_argument(
             '--nomedia', action='store_true', dest='no_media', default=False,
-            help='Do not profile MEDIA_URL and ADMIN_MEDIA_URL')
+            help='Do not profile MEDIA_URL'
+        )
         parser.add_argument(
             '--use-cprofile', action='store_true', dest='use_cprofile',
             default=False,
             help='Use cProfile if available, this is disabled per default '
-            'because of incompatibilities.')
+            'because of incompatibilities.'
+        )
         parser.add_argument(
             '--kcachegrind', action='store_true', dest='use_lsprof',
             default=False,
             help='Create kcachegrind compatible lsprof files, this requires '
-            'and automatically enables cProfile.')
+            'and automatically enables cProfile.'
+        )
 
         if USE_STATICFILES:
             parser.add_argument(
@@ -143,21 +151,6 @@ class Command(BaseCommand):
         import socket
         import errno
         from django.core.servers.basehttp import run
-        try:
-            from django.core.servers.basehttp import get_internal_wsgi_application as WSGIHandler
-        except ImportError:
-            from django.core.handlers.wsgi import WSGIHandler  # noqa
-
-        try:
-            from django.core.servers.basehttp import AdminMediaHandler
-            HAS_ADMINMEDIAHANDLER = True
-        except ImportError:
-            HAS_ADMINMEDIAHANDLER = False
-
-        try:
-            from django.core.servers.basehttp import WSGIServerException as wsgi_server_exc_cls
-        except ImportError:  # Django 1.6
-            wsgi_server_exc_cls = socket.error
 
         if args:
             raise CommandError('Usage is runserver %s' % self.args)
@@ -175,9 +168,9 @@ class Command(BaseCommand):
         if not port.isdigit():
             raise CommandError("%r is not a valid port number." % port)
 
-        use_reloader = options.get('use_reloader', True)
+        use_reloader = options['use_reloader']
         shutdown_message = options.get('shutdown_message', '')
-        no_media = options.get('no_media', False)
+        no_media = options['no_media']
         quit_command = (sys.platform == 'win32') and 'CTRL-BREAK' or 'CONTROL-C'
 
         def inner_run():
@@ -188,8 +181,8 @@ class Command(BaseCommand):
                 HAS_HOTSHOT = True
             except ImportError:
                 HAS_HOTSHOT = False  # python 3.x
-            USE_CPROFILE = options.get('use_cprofile', False)
-            USE_LSPROF = options.get('use_lsprof', False)
+            USE_CPROFILE = options['use_cprofile']
+            USE_LSPROF = options['use_lsprof']
             if USE_LSPROF:
                 USE_CPROFILE = True
             if USE_CPROFILE:
@@ -205,9 +198,9 @@ class Command(BaseCommand):
             if not HAS_HOTSHOT and not USE_CPROFILE:
                 raise CommandError("Hotshot profile library not found. (and not using cProfile)")
 
-            prof_path = options.get('prof_path', '/tmp')
+            prof_path = options['prof_path']
 
-            prof_file = options.get('prof_file', '{path}.{duration:06d}ms.{time}')
+            prof_file = options['prof_file']
             if not prof_file.format(path='1', duration=2, time=3):
                 prof_file = '{path}.{duration:06d}ms.{time}'
                 print("Filename format is wrong. Default format used: '{path}.{duration:06d}ms.{time}'.")
@@ -220,9 +213,6 @@ class Command(BaseCommand):
                 static_url = getattr(settings, 'STATIC_URL', None)
                 if static_url:
                     exclude_paths.append(static_url)
-                admin_media_prefix = getattr(settings, 'ADMIN_MEDIA_PREFIX', None)
-                if admin_media_prefix:
-                    exclude_paths.append(admin_media_prefix)
                 return exclude_paths
 
             def make_profiler_handler(inner_handler):
@@ -267,40 +257,24 @@ class Command(BaseCommand):
             print("\nDjango version %s, using settings %r" % (django.get_version(), settings.SETTINGS_MODULE))
             print("Development server is running at http://%s:%s/" % (addr, port))
             print("Quit the server with %s." % quit_command)
-            path = options.get('admin_media_path', '')
-            if not path:
-                admin_media_path = os.path.join(django.__path__[0], 'contrib/admin/static/admin')
-                if os.path.isdir(admin_media_path):
-                    path = admin_media_path
-                else:
-                    path = os.path.join(django.__path__[0], 'contrib/admin/media')
             try:
-                handler = WSGIHandler()
-                if HAS_ADMINMEDIAHANDLER:
-                    handler = AdminMediaHandler(handler, path)
+                handler = get_internal_wsgi_application()
                 if USE_STATICFILES:
-                    use_static_handler = options.get('use_static_handler', True)
-                    insecure_serving = options.get('insecure_serving', False)
+                    use_static_handler = options['use_static_handler']
+                    insecure_serving = options['insecure_serving']
                     if use_static_handler and (settings.DEBUG or insecure_serving):
                         handler = StaticFilesHandler(handler)
                 handler = make_profiler_handler(handler)
-                run(addr, int(port), handler)
-            except wsgi_server_exc_cls as e:
+                run(addr, int(port), handler, threading=options['use_threading'])
+            except socket.error as e:
                 # Use helpful error messages instead of ugly tracebacks.
                 ERRORS = {
                     errno.EACCES: "You don't have permission to access that port.",
                     errno.EADDRINUSE: "That port is already in use.",
                     errno.EADDRNOTAVAIL: "That IP address can't be assigned-to.",
                 }
-                if not isinstance(e, socket.error):  # Django < 1.6
-                    ERRORS[13] = ERRORS.pop(errno.EACCES)
-                    ERRORS[98] = ERRORS.pop(errno.EADDRINUSE)
-                    ERRORS[99] = ERRORS.pop(errno.EADDRNOTAVAIL)
                 try:
-                    if not isinstance(e, socket.error):  # Django < 1.6
-                        error_text = ERRORS[e.args[0].args[0]]
-                    else:
-                        error_text = ERRORS[e.errno]
+                    error_text = ERRORS[e.errno]
                 except (AttributeError, KeyError):
                     error_text = str(e)
                 sys.stderr.write(self.style.ERROR("Error: %s" % error_text) + '\n')
