@@ -11,7 +11,8 @@ import django_extensions  # noqa
 from django_extensions.db.fields import AutoSlugField
 
 from .testapp.models import ChildSluggedTestModel, SluggedTestModel, \
-    FKSluggedTestModel, FKSluggedTestModelCallable, \
+    SluggedTestNoOverwriteOnAddModel, FKSluggedTestModel, \
+    FKSluggedTestModelCallable, FunctionSluggedTestModel, \
     ModelMethodSluggedTestModel
 
 
@@ -93,7 +94,7 @@ class AutoSlugFieldTest(TestCase):
         n.save()
         self.assertEqual(n.slug, '-3')
 
-    def test_callable_slug_source(self):
+    def test_callable_method_slug_source(self):
         m = ModelMethodSluggedTestModel(title='-foo')
         m.save()
         self.assertEqual(m.slug, 'the-title-is-foo')
@@ -105,6 +106,18 @@ class AutoSlugFieldTest(TestCase):
         n.save()
         self.assertEqual(n.slug, 'the-title-is-foo-2')
 
+    def test_callable_function_slug_source(self):
+        m = FunctionSluggedTestModel(title='-foo')
+        m.save()
+        self.assertEqual(m.slug, 'the-title-is-foo')
+
+        n = FunctionSluggedTestModel(title='-foo')
+        n.save()
+        self.assertEqual(n.slug, 'the-title-is-foo-2')
+
+        n.save()
+        self.assertEqual(n.slug, 'the-title-is-foo-2')
+
     def test_inheritance_creates_next_slug(self):
         m = SluggedTestModel(title='foo')
         m.save()
@@ -131,18 +144,60 @@ class AutoSlugFieldTest(TestCase):
         m.save()
         self.assertEqual(m.slug, 'the-title-is-foo')
 
+    def test_copy_model_generates_new_slug(self):
+        m = SluggedTestModel(title='foo')
+        m.save()
+        self.assertEqual(m.slug, 'foo')
+
+        m.pk = None
+        m.save()
+        self.assertEqual(m.slug, 'foo-2')
+
+    def test_copy_model_generates_new_slug_no_overwrite_on_add(self):
+        m = SluggedTestNoOverwriteOnAddModel(title='foo')
+        m.save()
+        self.assertEqual(m.slug, 'foo')
+
+        m.pk = None
+        m.slug = None
+        m.save()
+        self.assertEqual(m.slug, 'foo-2')
+
+    def test_populate_from_does_not_allow_bytes(self):
+        if six.PY3:
+            with pytest.raises(TypeError):
+                AutoSlugField(populate_from=b'bytes')
+
+            with pytest.raises(TypeError):
+                AutoSlugField(populate_from=[b'bytes'])
+
+    def test_populate_from_must_allow_string_or_list_str_or_tuple_str(self):
+        AutoSlugField(populate_from='str')
+        AutoSlugField(populate_from=['str'])
+        AutoSlugField(populate_from=('str', ))
+
+    def test_slug_argument_priority(self):
+        m = SluggedTestModel(slug='slug', title='title')
+        m.save()
+        self.assertEqual(m.slug, 'title')
+
+    def test_slug_argument_priority_no_overwrite_on_add(self):
+        m = SluggedTestNoOverwriteOnAddModel(slug='slug', title='title')
+        m.save()
+        self.assertEqual(m.slug, 'slug')
+
 
 class MigrationTest(TestCase):
     def safe_exec(self, string, value=None):
-        l = {}
+        dct = {}
         try:
-            exec(force_bytes(string), globals(), l)
+            exec(force_bytes(string), globals(), dct)
         except Exception as e:
             if value:
                 self.fail("Could not exec %r (from value %r): %s" % (string.strip(), value, e))
             else:
                 self.fail("Could not exec %r: %s" % (string.strip(), e))
-        return l
+        return dct
 
     def test_17_migration(self):
         """
@@ -164,13 +219,18 @@ class MigrationTest(TestCase):
         output = writer.as_string()
         # It should NOT be unicode.
         if django.VERSION < (1, 11):
-            self.assertIsInstance(output, six.binary_type,
-                                "Migration as_string returned unicode")
+            self.assertIsInstance(output, six.binary_type, "Migration as_string returned unicode")
         else:
             # As of Django 1.11 MigrationWriter.as_string returns unicode not bytes
-            self.assertIsInstance(output, six.text_type,
-                                "Migration as_string returned bytes")
+            self.assertIsInstance(output, six.text_type, "Migration as_string returned bytes")
         # We don't test the output formatting - that's too fragile.
         # Just make sure it runs for now, and that things look alright.
         result = self.safe_exec(output)
         self.assertIn("Migration", result)
+
+    def test_stable_deconstruct(self):
+        slug_field = SluggedTestModel._meta.get_field('slug')
+        construction_values = slug_field.deconstruct()
+        m = SluggedTestModel(title='foo')
+        m.save()
+        self.assertEqual(slug_field.deconstruct(), construction_values)
