@@ -32,16 +32,35 @@ class Note(models.Model):
         app_label = 'django_extensions'
 
 
+class Personality(models.Model):
+    description = models.CharField(max_length=50)
+
+
+class Club(models.Model):
+    name = models.CharField(max_length=50)
+
+
 class Person(models.Model):
     name = models.ForeignKey(Name, on_delete=models.CASCADE)
     age = models.PositiveIntegerField()
     children = models.ManyToManyField('self')
     notes = models.ManyToManyField(Note)
+    personality = models.OneToOneField(
+        Personality,
+        null=True,
+        on_delete=models.CASCADE)
+    clubs = models.ManyToManyField(Club, through='testapp.Membership')
 
     class Meta:
         app_label = 'django_extensions'
 
 
+class Membership(models.Model):
+    person = models.ForeignKey(Person, on_delete=models.CASCADE)
+    club = models.ForeignKey(Club, on_delete=models.CASCADE)
+    created = models.DateTimeField(auto_now=True)
+
+
 class Post(ActivatorModel):
     title = models.CharField(max_length=255)
 
@@ -49,6 +68,25 @@ class Post(ActivatorModel):
         app_label = 'django_extensions'
 
 
+class PostWithTitleOrdering(Post):
+    class Meta:
+        proxy = True
+        ordering = ['title']
+
+
+class AbstractInheritanceTestModelParent(models.Model):
+    my_field_that_my_child_will_inherit = models.BooleanField()
+
+    class Meta:
+        app_label = 'django_extensions'
+        abstract = True
+
+
+class AbstractInheritanceTestModelChild(AbstractInheritanceTestModelParent):
+    class Meta:
+        app_label = 'django_extensions'
+
+
 class SluggedTestModel(models.Model):
     title = models.CharField(max_length=42)
     slug = AutoSlugField(populate_from='title')
@@ -62,6 +100,18 @@ class ChildSluggedTestModel(SluggedTestModel):
         app_label = 'django_extensions'
 
 
+class SluggedTestNoOverwriteOnAddModel(models.Model):
+    title = models.CharField(max_length=42)
+    slug = AutoSlugField(populate_from='title', overwrite_on_add=False)
+
+    class Meta:
+        app_label = 'django_extensions'
+
+
+def get_readable_title(instance):
+    return "The title is {}".format(instance.title)
+
+
 class ModelMethodSluggedTestModel(models.Model):
     title = models.CharField(max_length=42)
     slug = AutoSlugField(populate_from='get_readable_title')
@@ -70,7 +120,15 @@ class ModelMethodSluggedTestModel(models.Model):
         app_label = 'django_extensions'
 
     def get_readable_title(self):
-        return "The title is {}".format(self.title)
+        return get_readable_title(self)
+
+
+class FunctionSluggedTestModel(models.Model):
+    title = models.CharField(max_length=42)
+    slug = AutoSlugField(populate_from=get_readable_title)
+
+    class Meta:
+        app_label = 'django_extensions'
 
 
 class FKSluggedTestModel(models.Model):
@@ -206,3 +264,36 @@ class RandomCharTestModelPunctuation(models.Model):
 class TimestampedTestModel(TimeStampedModel):
     class Meta:
         app_label = 'django_extensions'
+
+
+class UnicodeVerboseNameModel(models.Model):
+    cafe = models.IntegerField(verbose_name=u'café')
+    parent_cafe = models.ForeignKey('self', related_name='children',
+                                    on_delete=models.CASCADE,
+                                    verbose_name='café latte')
+
+    class Meta:
+        app_label = 'django_extensions'
+        verbose_name = u'café unicode model'
+
+
+class Permission(models.Model):
+    text = models.CharField(max_length=32)
+    person = models.ForeignKey(Person, on_delete=models.CASCADE)
+
+
+class UniqueTestAppModel(models.Model):
+    global_id = models.CharField(max_length=32, unique=True)
+
+
+class SqlDiff(models.Model):
+    number = models.CharField(max_length=40, null=True, verbose_name='Chargennummer')
+    creator = models.CharField(max_length=20, null=True, blank=True)
+
+
+class SqlDiffUniqueTogether(models.Model):
+    aaa = models.CharField(max_length=20)
+    bbb = models.CharField(max_length=20)
+
+    class Meta:
+        unique_together = ['aaa', 'bbb']
